==> ae_sys_core_sh-0.0.2.tar.gz: ae_sys_core_sh-0.0.2/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# sys_core_sh portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_sys_core_sh/master?logo=python)](
    https://gitlab.com/ae-group/ae_sys_core_sh)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_sys_core_sh/coverage.svg)](
    https://ae-group.gitlab.io/ae_sys_core_sh/coverage/ae_sys_core_sh_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_sys_core_sh/mypy.svg)](
    https://ae-group.gitlab.io/ae_sys_core_sh/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_sys_core_sh/pylint.svg)](
    https://ae-group.gitlab.io/ae_sys_core_sh/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_sys_core_sh)](
    https://libraries.io/pypi/ae-sys-core-sh)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/#files)


## installation


Execute the following command for to use the ae.sys_core_sh module in your
application. It will install ae.sys_core_sh into your python (virtual) environment:
 
```shell script
pip install ae-sys-core-sh
```

If you instead want to contribute to this portion then first fork
[the ae_sys_core_sh repository at GitLab](https://gitlab.com/ae-group/ae_sys_core_sh "ae.sys_core_sh code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_sys_core_sh):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.sys_core_sh.html#module-ae.sys_core_sh
"ae_sys_core_sh documentation").

<!-- Common files version 0.0.49 deployed  version 0.0.1 (with 0.0.49)
     to https://gitlab.com/ae-group as ae_sys_core_sh module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project as ae-sys-core-sh package.
-->

==> ae_sys_core_sh-0.1.4.tar.gz: ae_sys_core_sh-0.1.4/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# sys_core_sh portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_sys_core_sh/master?logo=python)](
    https://gitlab.com/ae-group/ae_sys_core_sh)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_sys_core_sh/coverage.svg)](
    https://ae-group.gitlab.io/ae_sys_core_sh/coverage/ae_sys_core_sh_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_sys_core_sh/mypy.svg)](
    https://ae-group.gitlab.io/ae_sys_core_sh/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_sys_core_sh/pylint.svg)](
    https://ae-group.gitlab.io/ae_sys_core_sh/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_sys_core_sh)](
    https://libraries.io/pypi/ae-sys-core-sh)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_sys_core_sh)](
    https://pypi.org/project/ae-sys-core-sh/#files)


## installation


Execute the following command for to use the ae.sys_core_sh module in your
application. It will install ae.sys_core_sh into your python (virtual) environment:
 
```shell script
pip install ae-sys-core-sh
```

If you instead want to contribute to this portion then first fork
[the ae_sys_core_sh repository at GitLab](https://gitlab.com/ae-group/ae_sys_core_sh "ae.sys_core_sh code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_sys_core_sh):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.sys_core_sh.html#module-ae.sys_core_sh
"ae_sys_core_sh documentation").

<!-- Common files version 0.0.60 deployed version 0.1.3 (with 0.0.60)
     to https://gitlab.com/ae-group as ae_sys_core_sh module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-sys-core-sh as namespace portion ae-sys-core-sh.
-->
